diff libpurple/protocols/msn/msn-utils.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 8cf610a18481
children f2a4b05407d7
line wrap: on
line diff
--- a/libpurple/protocols/msn/msn-utils.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/msn/msn-utils.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file msn-utils.c Utility functions
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -110,7 +110,7 @@
 		}
 	}
 
-	cur = g_strdup(gaim_url_decode(pre->str));
+	cur = g_strdup(purple_url_decode(pre->str));
 	g_string_free(pre, TRUE);
 
 	if (pre_ret != NULL)
@@ -118,7 +118,7 @@
 	else
 		g_free(cur);
 
-	cur = g_strdup(gaim_url_decode(post->str));
+	cur = g_strdup(purple_url_decode(post->str));
 	g_string_free(post, TRUE);
 
 	if (post_ret != NULL)
@@ -129,7 +129,7 @@
 
 /*
  * We need this because we're only supposed to encode spaces in the font
- * names. gaim_url_encode() isn't acceptable.
+ * names. purple_url_encode() isn't acceptable.
  */
 static const char *
 encode_spaces(const char *str)
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.